@@ -5,7 +5,7 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="36"/>
-        <source>cuteTube-QML - 0.4.2</source>
+        <source>cuteTube-QML - 0.4.4</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -410,37 +410,37 @@
 <context>
     <name>PlaylistVideosView</name>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="88"/>
+        <location filename="../PlaylistVideosView.qml" line="90"/>
         <source>Multi-select</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="92"/>
         <source>Download video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="92"/>
         <source>Download audio</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="91"/>
+        <location filename="../PlaylistVideosView.qml" line="93"/>
         <source>Add to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="91"/>
+        <location filename="../PlaylistVideosView.qml" line="93"/>
         <source>Add to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="91"/>
+        <location filename="../PlaylistVideosView.qml" line="93"/>
         <source>Copy to clipboard</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="145"/>
+        <location filename="../PlaylistVideosView.qml" line="147"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
@@ -883,67 +883,67 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="81"/>
+        <location filename="../UserVideosView.qml" line="83"/>
         <source>You have subscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="85"/>
+        <location filename="../UserVideosView.qml" line="87"/>
         <source>You have unsubscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="138"/>
+        <location filename="../UserVideosView.qml" line="140"/>
         <source>Multi-select</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="140"/>
+        <location filename="../UserVideosView.qml" line="142"/>
         <source>Download video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="140"/>
+        <location filename="../UserVideosView.qml" line="142"/>
         <source>Download audio</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="141"/>
+        <location filename="../UserVideosView.qml" line="143"/>
         <source>Add to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="141"/>
+        <location filename="../UserVideosView.qml" line="143"/>
         <source>Add to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="141"/>
+        <location filename="../UserVideosView.qml" line="143"/>
         <source>Copy to clipboard</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="194"/>
+        <location filename="../UserVideosView.qml" line="196"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="236"/>
+        <location filename="../UserVideosView.qml" line="248"/>
         <source>Subscribers</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="250"/>
+        <location filename="../UserVideosView.qml" line="262"/>
         <source>Videos</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="273"/>
+        <location filename="../UserVideosView.qml" line="285"/>
         <source>Unsubscribe</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="273"/>
+        <location filename="../UserVideosView.qml" line="285"/>
         <source>Subscribe</source>
         <translation></translation>
     </message>
@@ -1054,54 +1054,67 @@
 <context>
     <name>VideoListDelegate</name>
     <message>
-        <location filename="../VideoListDelegate.qml" line="50"/>
+        <location filename="../VideoListDelegate.qml" line="52"/>
         <source>By </source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListDelegate.qml" line="50"/>
+        <location filename="../VideoListDelegate.qml" line="52"/>
         <source> on </source>
         <translation></translation>
     </message>
+    <message>
+        <location filename="../VideoListDelegate.qml" line="102"/>
+        <source>Views</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VideoListView</name>
     <message>
-        <location filename="../VideoListView.qml" line="85"/>
+        <location filename="../VideoListView.qml" line="87"/>
         <source>Multi-select</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="87"/>
+        <location filename="../VideoListView.qml" line="89"/>
         <source>Download video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="87"/>
+        <location filename="../VideoListView.qml" line="89"/>
         <source>Download audio</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="88"/>
+        <location filename="../VideoListView.qml" line="90"/>
         <source>Add to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="88"/>
+        <location filename="../VideoListView.qml" line="90"/>
         <source>Add to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="88"/>
+        <location filename="../VideoListView.qml" line="90"/>
         <source>Copy to clipboard</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="142"/>
+        <location filename="../VideoListView.qml" line="144"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>VideoPlaybackView</name>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="60"/>
+        <source>Error: Unable to retrieve video</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>YouTube</name>
     <message>
@@ -1289,7 +1302,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="238"/>
+        <location filename="../scripts/mainscripts.js" line="237"/>
         <source>Search </source>
         <translation type="unfinished"></translation>
     </message>
