@@ -16,9 +16,13 @@
         <translation type="obsolete">cuteTube-QML - 0.4.1</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="36"/>
         <source>cuteTube-QML - 0.4.2</source>
-        <translation>cuteTube-QML - 0.4.2</translation>
+        <translation type="obsolete">cuteTube-QML - 0.4.2</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="36"/>
+        <source>cuteTube-QML - 0.4.4</source>
+        <translation>cuteTube-QML - 0.4.4 in deutsch</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="48"/>
@@ -458,37 +462,37 @@
 <context>
     <name>PlaylistVideosView</name>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="88"/>
+        <location filename="../PlaylistVideosView.qml" line="90"/>
         <source>Multi-select</source>
         <translation>Mehrfachauswahl</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="92"/>
         <source>Download video</source>
         <translation>Video herrunterladen</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="92"/>
         <source>Download audio</source>
         <translation>Audio herrunterladen</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="91"/>
+        <location filename="../PlaylistVideosView.qml" line="93"/>
         <source>Add to favourites</source>
         <translation>Zu Favoriten hinzufügen</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="91"/>
+        <location filename="../PlaylistVideosView.qml" line="93"/>
         <source>Add to playlist</source>
         <translation>Zur Wiedergabeliste hinzufügen</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="91"/>
+        <location filename="../PlaylistVideosView.qml" line="93"/>
         <source>Copy to clipboard</source>
         <translation>In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="145"/>
+        <location filename="../PlaylistVideosView.qml" line="147"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
@@ -670,7 +674,7 @@
     <message>
         <location filename="../SettingsDialog.qml" line="21"/>
         <source>Light</source>
-        <translation>Licht</translation>
+        <translation>Hell</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="21"/>
@@ -939,67 +943,67 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="81"/>
+        <location filename="../UserVideosView.qml" line="83"/>
         <source>You have subscribed to &apos;</source>
         <translation>Du hast ein Abonnement bei</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="85"/>
+        <location filename="../UserVideosView.qml" line="87"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Abonnement gekündigt bei</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="138"/>
+        <location filename="../UserVideosView.qml" line="140"/>
         <source>Multi-select</source>
         <translation>Mehrfachauswahl</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="140"/>
+        <location filename="../UserVideosView.qml" line="142"/>
         <source>Download video</source>
         <translation>Video herrunterladen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="140"/>
+        <location filename="../UserVideosView.qml" line="142"/>
         <source>Download audio</source>
         <translation>Audio herrunterladen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="141"/>
+        <location filename="../UserVideosView.qml" line="143"/>
         <source>Add to favourites</source>
         <translation>Zu Favoriten hinzufügen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="141"/>
+        <location filename="../UserVideosView.qml" line="143"/>
         <source>Add to playlist</source>
         <translation>Zur Wiedergabeliste hinzufügen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="141"/>
+        <location filename="../UserVideosView.qml" line="143"/>
         <source>Copy to clipboard</source>
         <translation>In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="194"/>
+        <location filename="../UserVideosView.qml" line="196"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="236"/>
+        <location filename="../UserVideosView.qml" line="248"/>
         <source>Subscribers</source>
         <translation>Abonnenten</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="250"/>
+        <location filename="../UserVideosView.qml" line="262"/>
         <source>Videos</source>
         <translation>Videos</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="273"/>
+        <location filename="../UserVideosView.qml" line="285"/>
         <source>Unsubscribe</source>
         <translation>Abonnement kündigen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="273"/>
+        <location filename="../UserVideosView.qml" line="285"/>
         <source>Subscribe</source>
         <translation>Abonnieren</translation>
     </message>
@@ -1110,54 +1114,67 @@
 <context>
     <name>VideoListDelegate</name>
     <message>
-        <location filename="../VideoListDelegate.qml" line="50"/>
+        <location filename="../VideoListDelegate.qml" line="52"/>
         <source>By </source>
         <translation>Von </translation>
     </message>
     <message>
-        <location filename="../VideoListDelegate.qml" line="50"/>
+        <location filename="../VideoListDelegate.qml" line="52"/>
         <source> on </source>
         <translation> am </translation>
     </message>
+    <message>
+        <location filename="../VideoListDelegate.qml" line="102"/>
+        <source>Views</source>
+        <translation>Aufrufe</translation>
+    </message>
 </context>
 <context>
     <name>VideoListView</name>
     <message>
-        <location filename="../VideoListView.qml" line="85"/>
+        <location filename="../VideoListView.qml" line="87"/>
         <source>Multi-select</source>
         <translation>Mehrfachauswahl</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="87"/>
+        <location filename="../VideoListView.qml" line="89"/>
         <source>Download video</source>
         <translation>Video herrunterladen</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="87"/>
+        <location filename="../VideoListView.qml" line="89"/>
         <source>Download audio</source>
         <translation>Audio herrunterladen</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="88"/>
+        <location filename="../VideoListView.qml" line="90"/>
         <source>Add to favourites</source>
         <translation>Zu Favoriten hinzufügen</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="88"/>
+        <location filename="../VideoListView.qml" line="90"/>
         <source>Add to playlist</source>
         <translation>Zur Wiedergabeliste hinzufügen</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="88"/>
+        <location filename="../VideoListView.qml" line="90"/>
         <source>Copy to clipboard</source>
         <translation>In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="142"/>
+        <location filename="../VideoListView.qml" line="144"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
 </context>
+<context>
+    <name>VideoPlaybackView</name>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="60"/>
+        <source>Error: Unable to retrieve video</source>
+        <translation>Fehler: Kann Video nicht empfangen</translation>
+    </message>
+</context>
 <context>
     <name>XHamsterInfoView</name>
     <message>
@@ -1425,7 +1442,7 @@
         <translation>bewertung</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="238"/>
+        <location filename="../scripts/mainscripts.js" line="237"/>
         <source>Search </source>
         <translation>Suchlauf</translation>
     </message>
