@@ -187,7 +187,7 @@ function loadVideoInfo(video) {
     var loader = viewsModel.children[windowView.currentIndex + 1];
     windowView.currentItem.visible = false;
     loader.source = "VideoInfoView.qml";
-    loader.item.playVideo.connect(loadPlaybackView);
+//    loader.item.playVideo.connect(loadPlaybackView);
     loader.item.goToVideo.connect(loadVideoInfo);
     loader.item.authorClicked.connect(loadUserVideos);
     loader.item.search.connect(search);
